/*
 * Copyright: Nicholas P Wiebe (2008-2009) and Irmtraud M Meyer (2008-2009)
 * License: licensed under the GNU General Public License version 3 (GPLv3)
 * Tree.h
 *
 * This is only an interface class, and specifies the functionality available to other components of the program.
 * This is needed to abstract away the probability data type in the template class TreeImpl
 * See TreeImpl for implementation of this interface.
 * 			-jeff
 */

#ifndef TREE_H_
#define TREE_H_


#include <map>
using namespace std;


class Alignment;

// parent class that will be seen by mostly the rest of the program
class Tree {
public:

	static bool nonGapPair;
	static double rescaleFactor;

	// returns the base-2 logarithm of the felsenstein probabilities
	virtual double calcLogFelsPaired(Alignment & a, int pos5, int pos3) = 0;
	virtual double calcLogFelsUnpaired(Alignment & a, int pos) = 0;

	virtual void printAllLikelihoods(Alignment & a) = 0;

	// returns the length of the branch + the total length of all subtrees
	virtual double totalLength() = 0;

	virtual map<Tree*, unsigned int> getLeaf2SeqMap(vector<string> & SeqNames) = 0;

	virtual vector<string> getSeqNames() = 0;

	virtual string newickString() = 0;
};



#endif /* TREE_H_ */
